<?php
/**
 * Plugin Name: Registration and Authorization
 * Description: Advanced, convenient and ultra-fast user registration and authorization system with the ability to fine-tune page redirection
Lang: [EN/RU]
 
 * Plugin URI:  https://lumpx.com/wp-plugins/registration-and-authorize
 * Author URI:  https://lumpx.com
 * Author:      LumpX
 * Network: false
 * Version:     1.0.0
 *
 * Text Domain: registration-and-authorize
 * Domain Path: /lang
 * Requires at least: 5.2
 * Requires PHP: 5.4
 *
 * License:     GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 *
 * Network:    false

 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
**/

// Restrict
if(!defined('ABSPATH')) {
	die();
}

define('IQ_AUTH_ACCESS', true );
define('IQ_AUTH_PRO_VERSION', 0 );
define('IQ_AUTH_CORE_URL', plugin_dir_url( __FILE__ ) );
define('IQ_AUTH_CORE_DIR', plugin_dir_path( __FILE__ ) );
define('IQ_AUTH_PLUGIN_TAG', 'iqauth' ); // Do not change
define('IQ_AUTH_MENU_TAG', 'iq-auth-' ); // Do not change
define('IQ_AUTH_SECRET_CODE', 'oDkaErYFaueWIFLdP3pUg69liprq3iRKqPqzSzYTt0lK6jh12YZ5JBsp1LFTd58n' );
define('IQ_AUTH_TPL_DIR', IQ_AUTH_CORE_DIR.'/templates' );
define('IQ_AUTH_PLUGIN_DIR', plugin_basename(dirname(__FILE__)));

define('IQ_AUTH_AUTH_PAGE_DEF', 'iq-login' );
define('IQ_AUTH_REGIST_PAGE_DEF', 'iq-register' );
define('IQ_AUTH_LOST_PAGE_DEF', 'iq-lost' );
define('IQ_AUTH_CACHE_SETTINGS_FILE', 'iq-settings' );
define('IQ_AUTH_CORE_IMAGE_DIR', IQ_AUTH_CORE_DIR.'/assets/img' );
define('IQ_AUTH_CORE_IMAGE_URL', IQ_AUTH_CORE_URL.'/assets/img' );

// WIZARD
define('IQ_AUTH_WIZARD_PATH', IQ_AUTH_CORE_DIR.'/wizard' );
define('IQ_AUTH_WIZARD_URL', IQ_AUTH_CORE_URL.'/wizard' );

if ( ! class_exists( 'IQ_AUTH_CoreClass' ) ) {
	class IQ_AUTH_CoreClass {
		function initialize() {
			add_action('admin_enqueue_scripts', array($this, 'func_iq_auth_enqueue_admin'));
			add_action('wp_enqueue_scripts', array($this, 'func_iq_auth_enqueue_front'));
			add_action('admin_menu', 'iq_auth_pre_create_menu');
			add_action( 'plugins_loaded', array($this, 'func_iq_auth_load_plugin_textdomain' ));
			add_action( 'init', array($this, 'iq_init' ));
			add_action( 'init', array($this, 'func_iq_auth_load_ajax' ));
			add_action( 'init', array($this, 'func_iq_auth_custom_login'));
			
			add_action( 'init',              array($this, 'func_iq_auth_pages_redirect') );
			add_action( 'template_redirect', array($this, 'func_iq_auth_pages_redirect') );
			add_filter( 'request',           array($this, 'func_iq_auth_pages_redirect') );
			add_filter('pre_get_document_title', array($this, 'func_iq_auth_change_title'));
			
			// wizard
			add_action('admin_init', array($this, 'IQ_AUTH_redirect'));
			
			require_once IQ_AUTH_CORE_DIR.'/includes/inc_func.php';
		}
		
		function func_iq_auth_custom_login(){
			global $pagenow;
			if( 'wp-login.php' == $pagenow ) {
				$action = (isset($_GET['action'])) ? $_GET['action'] : '';
				if( ! $action || ( $action && ! in_array($action, array('logout', 'lostpassword', 'rp', 'resetpass')))) {
					$iq_auth_settings_arr = func_iq_auth_get_settings();
					if(isset($iq_auth_settings_arr['login_url'])) {
						$login_page = $iq_auth_settings_arr['login_url'];
					} else {
						$login_page = IQ_AUTH_AUTH_PAGE_DEF;
					}
					wp_redirect('/'.$login_page);
					exit();
				}
			 }
		}

		function func_iq_auth_load_ajax() {
			$modules_arr = func_iq_auth_get_modules();
			
			if(!isset($cIQ_AUTH_AjaxClass)) {
				require_once IQ_AUTH_CORE_DIR.'/includes/inc_ajax_class.php';
				$cIQ_AUTH_AjaxClass = new IQ_AUTH_AjaxClass();
			}
			
			// admin
			$names_admin = [
				'admin_iq_auth_UserEdit',
				'admin_iq_auth_UserEditDo',
				'admin_iq_auth_UserReload',
				'admin_iq_auth_WizardImportUsers',
				
				'admin_iq_auth_RedirectsAdd',
				'admin_iq_auth_RedirectsAddDo',
				'admin_iq_auth_RedirectsItemDelete',
				'admin_iq_auth_RedirectsItemReload',
			];
			for($i = 0; $i < count($names_admin); $i++) {
				$tmp = trim($names_admin[$i]);
				if(empty($tmp)) {
					continue;
				}
				add_action( 'wp_ajax_'.$tmp, array($cIQ_AUTH_AjaxClass, $tmp) );
			}
			
			if($modules_arr) {
				for($i = 0; $i < count($modules_arr); $i++) {
					$name = $modules_arr[$i];
					$file = IQ_AUTH_CORE_DIR.'/modules/'.$name.'/'.$name.'.php';
					if(file_exists($file)) {
						$type = 'adm_ajax';
						include $file;
						
						$type = 'web_ajax';
						include $file;
					}
				}
			}
			
			// front
			$names_front = [
				'web_iq_auth_LoginDo',
				'web_iq_auth_RegistDo',
				'web_iq_auth_LostDo',
				'web_iq_auth_RecoverDo',
				'web_iq_auth_RegistPage',
				'web_iq_auth_LostPage',
				'web_iq_auth_LoginPage',
			];
			for($i = 0; $i < count($names_front); $i++) {
				$tmp = trim($names_front[$i]);
				if(empty($tmp)) {
					continue;
				}
				add_action( 'wp_ajax_'.$tmp, array($cIQ_AUTH_AjaxClass, $tmp) );
				add_action( 'wp_ajax_nopriv_'.$tmp, array($cIQ_AUTH_AjaxClass, $tmp) );
			}
		}

		function iq_init() {
			ob_start();

			$modules_arr = func_iq_auth_get_modules();
			if($modules_arr) {
				for($i = 0; $i < count($modules_arr); $i++) {
					$name = $modules_arr[$i];
					$file = IQ_AUTH_CORE_DIR.'/modules/'.$name.'/'.$name.'.php';
					if(file_exists($file)) {
						$type = 'define';
						include $file;
					}
				}
			}
		}

		function func_iq_auth_change_title( $title ) {
			$iq_auth_settings_arr = func_iq_auth_get_settings();
			if(isset($iq_auth_settings_arr['login_url'])) {
				$login_page = $iq_auth_settings_arr['login_url'];
			} else {
				$login_page = IQ_AUTH_AUTH_PAGE_DEF;
			}
			if(isset($iq_auth_settings_arr['regist_url'])) {
				$regist_page = $iq_auth_settings_arr['regist_url'];
			} else {
				$regist_page = IQ_AUTH_REGIST_PAGE_DEF;
			}
			
			// lost_url
			if(isset($iq_auth_settings_arr['lost_url'])) {
				$lost_page = $iq_auth_settings_arr['lost_url'];
			} else {
				$lost_page = IQ_AUTH_LOST_PAGE_DEF;
			}
			
			if(get_query_var( $login_page )) {
				if(isset($iq_auth_settings_arr['login_title'])) {
					$title = $iq_auth_settings_arr['login_title'];
				}
			}
			else if(get_query_var( $regist_page )) {
				if(isset($iq_auth_settings_arr['regist_title'])) {
					$title = $iq_auth_settings_arr['regist_title'];
				}
			}
			else if(get_query_var( $lost_page )) {
				if(isset($iq_auth_settings_arr['lost_title'])) {
					$title = $iq_auth_settings_arr['lost_title'];
				}
			}
			return $title;
		}
		
		function func_iq_auth_pages_redirect( $vars = '' ) {
			$iq_auth_settings_arr = func_iq_auth_get_settings();
			if(isset($iq_auth_settings_arr['login_url'])) {
				$login_page = $iq_auth_settings_arr['login_url'];
			} else {
				$login_page = IQ_AUTH_AUTH_PAGE_DEF;
			}
			if(isset($iq_auth_settings_arr['regist_url'])) {
				$regist_page = $iq_auth_settings_arr['regist_url'];
			} else {
				$regist_page = IQ_AUTH_REGIST_PAGE_DEF;
			}
			
			// lost_url
			if(isset($iq_auth_settings_arr['lost_url'])) {
				$lost_page = $iq_auth_settings_arr['lost_url'];
			} else {
				$lost_page = IQ_AUTH_LOST_PAGE_DEF;
			}
			
			// redirects
			if(!isset($cIQAuthRedirects)) {
				require_once IQ_AUTH_CORE_DIR.'/includes/inc_redirects.php';
				$cIQAuthRedirects = new IQAuthRedirects();
			}
			$redirects_list = $cIQAuthRedirects->get();
	
			$hook = current_filter();
			if($hook == 'template_redirect') {
				if(get_query_var( $login_page )) {
					include IQ_AUTH_CORE_DIR.'/data/data_auth_index.php';
					die();
				}
				if(get_query_var( $regist_page )) {
					include IQ_AUTH_CORE_DIR.'/data/data_regist_index.php';
					die();
				}
				if(get_query_var( $lost_page )) {
					include IQ_AUTH_CORE_DIR.'/data/data_lost_index.php';
					die();
				}
				
				if($redirects_list) {
					foreach($redirects_list AS $data) {
						if(get_query_var( $data['page'] )) {
							switch($data['type']) {
								case 1: {
									// login page
									wp_redirect('/'.$login_page);
									break;
								}
								case 2: {
									// Registration page
									wp_redirect('/'.$regist_page);
									break;
								}
								case 3: {
									// Lost page
									wp_redirect('/'.$lost_page);
									break;
								}
							}
							die();
						}
					}
				}
			}
			if($hook == 'init') {
				global $wp_rewrite; 
				
				add_rewrite_endpoint( $login_page, EP_ROOT );
				add_rewrite_endpoint( $regist_page, EP_ROOT );
				add_rewrite_endpoint( $lost_page, EP_ROOT );
				
				if($redirects_list) {
					foreach($redirects_list AS $data) {
						add_rewrite_endpoint( $data['page'], EP_ROOT );
					}
				}
				$wp_rewrite->flush_rules();
			}
			if($hook == 'request') {
				
				if(isset ( $vars[$login_page] )
				&& empty ( $vars[$login_page] )
				&& $vars[$login_page] = 'default') {
					
				}
				
				if(isset ( $vars[$regist_page] )
				&& empty ( $vars[$regist_page] )
				&& $vars[$regist_page] = 'default') {
					
				}
				
				if(isset ( $vars[$lost_page] )
				&& empty ( $vars[$lost_page] )
				&& $vars[$lost_page] = 'default') {
					
				}
				
				if($redirects_list) {
					foreach($redirects_list AS $data) {
						if(isset ( $vars[$data['page']] )
						&& empty ( $vars[$data['page']] )
						&& $vars[$data['page']] = 'default') {
							
						}
					}
				}
			}

			return $vars;
		}

		static function func_iq_auth_activation() {
			if(!isset($cIQAuthClass)) {
				require_once IQ_AUTH_CORE_DIR.'/includes/inc_auth.php';
				$cIQAuthClass = new IQAuthClass();
			}
			$cIQAuthClass->createDB();
			
			// redirects
			if(!isset($cIQAuthRedirects)) {
				require_once IQ_AUTH_CORE_DIR.'/includes/inc_redirects.php';
				$cIQAuthRedirects = new IQAuthRedirects();
			}
			$cIQAuthRedirects->createDB();
			
			
			$modules_arr = func_iq_auth_get_modules();
			if($modules_arr) {
				for($i = 0; $i < count($modules_arr); $i++) {
					$name = $modules_arr[$i];
					$file = IQ_AUTH_CORE_DIR.'/modules/'.$name.'/'.$name.'.php';
					if(file_exists($file)) {
						$type = 'define';
						include $file;
						$type = 'activation';
						include $file;
					}
				}
			}
			
			flush_rewrite_rules();
			add_option('func_iq_auth_do_activation_redirect', true);
		}
		
		// wizard
		function IQ_AUTH_redirect() {
			if (get_option('func_iq_auth_do_activation_redirect', false)) {
				delete_option('func_iq_auth_do_activation_redirect');
				wp_redirect( '/wp-admin/admin.php?page='.IQ_AUTH_MENU_TAG.'wizard' );
			}
		}

		public static function func_iq_auth_deactivation() {
			if(!isset($cIQAuthClass)) {
				require_once IQ_AUTH_CORE_DIR.'/includes/inc_auth.php';
				$cIQAuthClass = new IQAuthClass();
			}
			$cIQAuthClass->removeDB();
			
			// redirects
			if(!isset($cIQAuthRedirects)) {
				require_once IQ_AUTH_CORE_DIR.'/includes/inc_redirects.php';
				$cIQAuthRedirects = new IQAuthRedirects();
			}
			$cIQAuthRedirects->removeDB();
			
			$modules_arr = func_iq_auth_get_modules();
			if($modules_arr) {
				for($i = 0; $i < count($modules_arr); $i++) {
					$name = $modules_arr[$i];
					$file = IQ_AUTH_CORE_DIR.'/modules/'.$name.'/'.$name.'.php';
					if(file_exists($file)) {
						$type = 'define';
						include $file;
						$type = 'deactivation';
						include $file;
					}
				}
			}
			flush_rewrite_rules();
		}

		public static function func_iq_auth_uninstall() {
		}

		function func_iq_auth_enqueue_front() {
			wp_enqueue_style('iq_auth_FrontViewStyle', IQ_AUTH_CORE_URL.'/assets/front/css/styles.css', false, '1.0');
			wp_enqueue_script('iq_auth_FrontViewScript', IQ_AUTH_CORE_URL.'/assets/front/js/scripts.js', false, '1.0');
			
			// localize
			wp_localize_script( 'iq_auth_FrontViewScript', 'iq_auth_front_unique', array(
					'ajax_url' => admin_url( 'admin-ajax.php' ),
				)
			);
			
			// icofont
			wp_enqueue_style('iq_auth_FrontIconsViewScript', IQ_AUTH_CORE_URL. '/assets/icofont/icofont.min.css', false, '1.0');
			
			// pop
			wp_enqueue_style('iq_auth_FrontPopStyle', IQ_AUTH_CORE_URL.'/assets/front/css/pop.css', false, '1.0');
			wp_enqueue_script('iq_auth_FrontPopScript', IQ_AUTH_CORE_URL.'/assets/front/js/pop.js', false, '1.0');
		}

		function func_iq_auth_enqueue_admin() {
			wp_enqueue_style('iq_auth_AdminViewStyle', IQ_AUTH_CORE_URL.'/assets/admin/css/styles.css', false, '1.1');
			wp_enqueue_style('iq_auth_AdminLoaderStyle', IQ_AUTH_CORE_URL.'/assets/admin/css/loader.css', false, '1.0');
			wp_enqueue_script('iq_auth_AdminViewScript', IQ_AUTH_CORE_URL.'/assets/admin/js/scripts.js', false, '1.0');
			
			// localize
			wp_localize_script( 'iq_auth_AdminViewScript', 'iq_auth_unique', array(
					'ajax_url' => admin_url( 'admin-ajax.php' ),
				)
			);
			
			// icofont
			wp_enqueue_style('iq_auth_IconsViewStyle', IQ_AUTH_CORE_URL. '/assets/icofont/icofont.min.css', false, '1.0');
			
			// pop
			wp_enqueue_style('iq_auth_AdminPopStyle', IQ_AUTH_CORE_URL.'/assets/admin/css/pop.css', false, '1.0');
			wp_enqueue_script('iq_auth_AdminPopScript', IQ_AUTH_CORE_URL.'/assets/admin/js/pop.js', false, '1.0');
			
			// redirects
			wp_enqueue_script('iq_auth_AdminRedirectsScript', IQ_AUTH_CORE_URL.'/assets/admin/js/redirects.js', false, '1.0');
			wp_localize_script( 'iq_auth_AdminRedirectsScript', 'iq_auth_redirects_unique', array(
					'ajax_url' => admin_url( 'admin-ajax.php' ),
				)
			);
			
			// WIZARD
			wp_enqueue_style('iq_auth_AdminWizardLoaderStyle', IQ_AUTH_WIZARD_URL.'/assets/css/wizard_loader.css', false, '1.0');
			wp_enqueue_style('iq_auth_AdminWizardStyle', IQ_AUTH_WIZARD_URL.'/assets/css/wizard.css', false, '1.0');
			wp_enqueue_script('iq_auth_AdminWizardScript', IQ_AUTH_WIZARD_URL.'/assets/js/wizard.js', false, '1.0');
			wp_localize_script( 'iq_auth_AdminWizardScript', 'iq_auth_wizard_unique', array(
					'ajax_url' => admin_url( 'admin-ajax.php' ),
				)
			);
			
			
			$modules_arr = func_iq_auth_get_modules();
			if($modules_arr) {
				for($i = 0; $i < count($modules_arr); $i++) {
					$name = $modules_arr[$i];
					$file = IQ_AUTH_CORE_DIR.'/modules/'.$name.'/'.$name.'.php';
					if(file_exists($file)) {
						$type = 'adm_enqueue';
						include $file;
					}
				}
			}
		}
		function func_iq_auth_load_plugin_textdomain() {
			load_plugin_textdomain( 'registration-and-authorize', false, dirname( plugin_basename( __FILE__ ) ). '/lang/' );
		}
	}
}

register_activation_hook( __FILE__, array( 'IQ_AUTH_CoreClass', 'func_iq_auth_activation' ) );
register_deactivation_hook( __FILE__, array( 'IQ_AUTH_CoreClass', 'func_iq_auth_deactivation' ) );
register_uninstall_hook( __FILE__, array( 'IQ_AUTH_CoreClass', 'func_iq_auth_uninstall' ) );

$cIQ_AUTH_CoreClass = new IQ_AUTH_CoreClass();
$cIQ_AUTH_CoreClass->initialize();