<?php
// Restrict
if(!defined('ABSPATH') || !defined('IQ_AUTH_CORE_DIR')) {
	die();
}

$iq_auth_settings_arr = func_iq_auth_get_settings();

// def inputs
$DefArr['login'] = [
	'name' => esc_html__('Login', 'registration-and-authorize'),
	'regex' => '/^(?=.*[A-Za-zА-Яа-яёґєії0-9])[A-Za-zА-Яа-яёґєії][A-Za-zА-Яа-яёґєії\d .-]{0,19}$/',
	'min' => 2,
	'max' => 64,
	'regex_text' => esc_html__('Login can contain only letters and numbers + (maximum 1 space, signs ".", "-"). The first character must be a letter', 'registration-and-authorize'),
];
$DefArr['email'] = [
	'name' => 'Email',
	'regex' => '/^([A-Za-z0-9_\-\.])+\@([A-Za-z0-9_\-\.])+\.([A-Za-z]{2,4})$/',
	'min' => 2,
	'max' => 64,
	'regex_text' => '',
];
$DefArr['pass'] = [
	'name' => esc_html__('Password', 'registration-and-authorize'),
	'regex' => '/^[A-Za-z0-9_\-\.]+$/',
	'min' => 2,
	'max' => 64,
	'regex_text' => esc_html__('The password can contain only letters of the Latin alphabet and / or numbers (the following characters are available: "_", "-" and ".")', 'registration-and-authorize'),
];

?>
<div class="iq_auth_core_block">
    <div class="iq_auth_list_block iq_auth_hided">
        <h2 class="iq_auth_head_block">
            <?php echo esc_html__('General settings', 'registration-and-authorize'); ?>
        </h2>
		<?php
		################
		##### POST #####
		################
		$bErr = false;
		$szMsg = '';
		if(isset($_POST['form_save'])) {
			// auth_redirect
			$iq_auth_settings_arr['auth_redirect'] = '';
			if(isset($_POST['auth_redirect'])) {
				$iq_auth_settings_arr['auth_redirect'] = sanitize_text_field($_POST['auth_redirect']);
			}
			// captcha_pub
			$iq_auth_settings_arr['captcha_pub'] = '';
			if(isset($_POST['captcha_pub'])) {
				$iq_auth_settings_arr['captcha_pub'] = sanitize_text_field($_POST['captcha_pub']);
			}
			// captcha_secret
			$iq_auth_settings_arr['captcha_secret'] = '';
			if(isset($_POST['captcha_secret'])) {
				$iq_auth_settings_arr['captcha_secret'] = sanitize_text_field($_POST['captcha_secret']);
			}
			// captcha_limit_free
			$iq_auth_settings_arr['captcha_limit_free'] = 3;
			if(isset($_POST['captcha_limit_free'])) {
				$iq_auth_settings_arr['captcha_limit_free'] = (int)sanitize_text_field($_POST['captcha_limit_free']);
			}
			// logo_width
			$iq_auth_settings_arr['logo_width'] = 200;
			if(isset($_POST['logo_width'])) {
				$iq_auth_settings_arr['logo_width'] = (int)sanitize_text_field($_POST['logo_width']);
			}
			
			// logo_enable
			$iq_auth_settings_arr['logo_enable'] = false;
			if(isset($_POST['logo_enable']) && $_POST['logo_enable'] == 'on') {
				$iq_auth_settings_arr['logo_enable'] = true;
			}
			
			// length
			foreach($DefArr AS $key => $data) {
				$iMin = $data['min'];
				$iMax = $data['max'];
				if(isset($_POST[$key.'_length_min'])) {
					$iMin = (int)sanitize_text_field($_POST[$key.'_length_min']);
				}
				if(isset($_POST[$key.'_length_max'])) {
					$iMax = (int)sanitize_text_field($_POST[$key.'_length_max']);
				}
				
				if($iMax < $iMin) {
					$szMsg = esc_html__(sprintf('The maximum length of the field «%s» cannot be less than the minimum length', $data['name']), 'registration-and-authorize');
					$bErr = true;
				}
				
				if($bErr) {
					break;
				}
				
				$iq_auth_settings_arr[$key.'_length'] = $iMin.':'.$iMax;
				
				$iq_auth_settings_arr[$key.'_regex'] = $data['regex'];
				if(isset($_POST[$key.'_regex'])) {
					$iq_auth_settings_arr[$key.'_regex'] = trim($_POST[$key.'_regex']);
				}
				
				// regex_text
				$iq_auth_settings_arr[$key.'_regex_text'] = $data['regex_text'];
				if(isset($_POST[$key.'_regex_text'])) {
					$iq_auth_settings_arr[$key.'_regex_text'] = trim($_POST[$key.'_regex_text']);
				}
			}
			
			if(!$bErr) {
				// Logotype
				if(isset($_FILES['form_logo']) && !empty($_FILES['form_logo']) && !empty($_FILES['form_logo']['tmp_name'])) {
					$File = $_FILES['form_logo'];
					$AllowedExtsFormats = array("png", "svg");
					$FileFormat = explode('.', $File['name']);
					$FileFormat = array_pop($FileFormat);
					if(!in_array($FileFormat, $AllowedExtsFormats, true)) {
						$szMsg = esc_html__('The logo was not loaded. Supported logo formats: PNG, SVG', 'registration-and-authorize');
						$bErr = true;
					} else {
						$FileType = $File['type'];
						if($FileType != 'image/png' && $FileType != 'image/svg+xml') {
							$szMsg = esc_html__('The logo was not loaded. Supported logo formats: PNG, SVG', 'registration-and-authorize');
							$bErr = true;
						} else {
							$FileName = 'logo_'.date('dmYHis').'.'.$FileFormat;
							$DirOut = IQ_AUTH_CORE_IMAGE_DIR;
							if(!move_uploaded_file($File['tmp_name'], $DirOut.'/'.$FileName)) {
								$szMsg = esc_html__('Failed to save logo to directory', 'registration-and-authorize').': '.$DirOut;
								$bErr = true;
							} else {
								if(!file_exists($DirOut.'/'.$FileName)) {
									$szMsg = esc_html__('Failed to save logo', 'registration-and-authorize');
									$bErr = true;
								} else {
									$iq_auth_settings_arr['logo'] = $FileName;
								}
							}
						}
					}
				}
			}
			
			$bSave = func_iq_auth_updateSettings($iq_auth_settings_arr);
			if(!$bSave) {
				$szMsg = esc_html__('An error has occurred', 'registration-and-authorize');;
				$bErr = true;
			}
			
			if($bErr) {
				if(empty($szMsg)) {
					$szMsg = esc_html__('An error has occurred', 'registration-and-authorize');;
				}
			} else {
				$szMsg = esc_html__('Settings have been saved', 'registration-and-authorize');
			}
			
			if($bErr) {
				?>
				
				<div class="iq_auth_alert_block iq_auth_err">
					<?php echo esc_html($szMsg); ?>
				</div>
					
				<?php
			} else {
				?>
				
				<div class="iq_auth_alert_block iq_auth_ok">
					<?php echo esc_html($szMsg); ?>
				</div>
				
				<?php
			}
		}
		
		
		##############
		$FormVal = [
			'auth_redirect' => '',
			'captcha_pub' => '',
			'captcha_secret' => '',
			'captcha_limit_free' => 3,
			'form_logo' => '',
			'logo_width' => 200,
			'logo_enable' => '',
		];
		
		foreach($DefArr AS $key => $data) {
			$FormVal[$key.'_length'] = $data['min'].':'.$data['max'];
		}
		if(isset($iq_auth_settings_arr['logo_enable']) && (int)$iq_auth_settings_arr['logo_enable']) {
			$FormVal['logo_enable'] = 'checked';
		}
		if(isset($iq_auth_settings_arr['auth_redirect'])) {
			$FormVal['auth_redirect'] = $iq_auth_settings_arr['auth_redirect'];
		}
		if(isset($iq_auth_settings_arr['captcha_pub'])) {
			$FormVal['captcha_pub'] = $iq_auth_settings_arr['captcha_pub'];
		}
		if(isset($iq_auth_settings_arr['captcha_secret'])) {
			$FormVal['captcha_secret'] = $iq_auth_settings_arr['captcha_secret'];
		}
		if(isset($iq_auth_settings_arr['captcha_limit_free'])) {
			$FormVal['captcha_limit_free'] = (int)$iq_auth_settings_arr['captcha_limit_free'];
		}
		if(isset($iq_auth_settings_arr['logo_width'])) {
			$FormVal['logo_width'] = (int)$iq_auth_settings_arr['logo_width'];
		}
		if(isset($iq_auth_settings_arr['form_logo'])) {
			// $FormVal['form_logo'] = $iq_auth_settings_arr['form_logo'];
		}
		
		foreach($DefArr AS $key => $data) {
			if(isset($iq_auth_settings_arr[$key.'_length'])) {
				$FormVal[$key.'_length'] = $iq_auth_settings_arr[$key.'_length'];
			}
			$Exp = explode(':', $FormVal[$key.'_length']);
			$FormVal[$key.'_length_min'] = (int)$Exp[0];
			$FormVal[$key.'_length_max'] = (int)$Exp[1];
			
			$FormVal[$key.'_regex'] = $data['regex'];
			if(isset($iq_auth_settings_arr[$key.'_regex'])) {
				$FormVal[$key.'_regex'] = stripcslashes($iq_auth_settings_arr[$key.'_regex']);
			}
			
			$FormVal[$key.'_regex_text'] = $data['regex_text'];
			if(isset($iq_auth_settings_arr[$key.'_regex_text'])) {
				$FormVal[$key.'_regex_text'] = stripcslashes($iq_auth_settings_arr[$key.'_regex_text']);
			}
		}
		?>
		</div>
		
		<form method="POST" enctype="multipart/form-data">
			<input type="hidden" name="form_save" value="1">
			<div class="iq_auth_flexbox_tab iq_auth_flex_gap">
			
				<div class="iq_auth_flex_400">
					<!-- wizard -->
					<div class="iq_auth_list_block iq_auth_flex_300">
						<div class="iq_auth_block_setup">
							<div class="iq_auth_block_logo">
								<div class="iq_auth_block_centered iq_auth_align_center">
									<?php
									$img_url = IQ_AUTH_CORE_URL . '/assets/img/iq_authorization.png';
									?>
									<img src="<?php echo esc_url($img_url); ?>" class="iq_auth_img_logo">
								</div>
							</div>
							<div class="iq_auth_block_btn_setup">
								<a href="/wp-admin/admin.php?page=iq-auth-wizard" class="iq_auth_btn_setup">
									<?php echo esc_html__('Setup Wizard', 'registration-and-authorize'); ?>
								</a>
							</div>
						</div>
					</div>
							
					<div class="iq_auth_list_block iq_auth_flex_400 iq_auth_flexh">
						<ul class="iq_auth_ulcl">
						
							<!-- auth_redirect -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Redirect URL after authorization', 'registration-and-authorize'); ?>
								</div>
								<div class="iq_auth_flexbox_st iq_auth_flexbox_yc iq_auth_flex_gap_2">
									<div>
										<?php echo ((!empty($_SERVER['HTTPS'])) ? 'https' : 'http') . '://' . esc_url($_SERVER ['SERVER_NAME']) ?>
									</div>
									<div>
										<input type="text" id="auth_redirect" name="auth_redirect" class="iq_auth_input iq_auth_input_default iq_auth_padd_3 iq_auth_full_width_b iq_auth_max_w500" maxlength="250" placeholder="" value="<?php echo esc_attr($FormVal['auth_redirect']); ?>">
									</div>
								</div>
								<div class="iq_auth_li_about">
									<?php echo esc_html__('The user will be automatically redirected to this URL after successful authorization or registration on the site', 'registration-and-authorize'); ?>
								</div>
							</li>
							
							<!-- captcha_pub -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Public Key Captcha', 'registration-and-authorize'); ?>
								</div>
								<input type="text" id="captcha_pub" name="captcha_pub" class="iq_auth_input iq_auth_input_default iq_auth_full_width_b iq_auth_max_w500" maxlength="255" placeholder="" value="<?php echo esc_attr($FormVal['captcha_pub']); ?>">
							</li>
							
							<!-- captcha_secret -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Secret Key Captcha', 'registration-and-authorize'); ?>
								</div>
								<input type="text" id="captcha_secret" name="captcha_secret" class="iq_auth_input iq_auth_input_default iq_auth_full_width_b iq_auth_max_w500" maxlength="255" placeholder="" value="<?php echo esc_attr($FormVal['captcha_secret']); ?>">
								<div class="iq_auth_li_about">
									<?php echo esc_html__('Captcha keys can be obtained from the link', 'registration-and-authorize'); ?> https://www.google.com/recaptcha/admin/create
								</div>
							</li>
							
							<!-- captcha_limit_free -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Attempts before CAPTCHA is displayed (0 - always)', 'registration-and-authorize'); ?>
								</div>
								<input type="text" id="captcha_limit_free" name="captcha_limit_free" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="3" value="<?php echo esc_attr($FormVal['captcha_limit_free']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
							</li>
			
						</ul>
					</div>
					
					<div class="iq_auth_list_block iq_auth_flex_400 iq_auth_flexh">
						<h2 class="iq_auth_flextbl">
							<?php echo esc_html__('Logo', 'registration-and-authorize'); ?>
						</h2>
						<ul class="iq_auth_ulcl">
							<?php
							$logo_image = IQ_AUTH_CORE_IMAGE_URL.'/iq_auth_nologo.png';
							if(isset($iq_auth_settings_arr['logo'])) {
								$DirOut = IQ_AUTH_CORE_IMAGE_DIR;
								if(file_exists($DirOut.'/'.$iq_auth_settings_arr['logo'])) {
									$logo_image = IQ_AUTH_CORE_IMAGE_URL.'/'.$iq_auth_settings_arr['logo'];
								}
							}
							
							?>
							
							<!-- form_logo -->
							<li class="iq_auth_li">
								<div class="iq_auth_flexbox_tab iq_auth_flex_gap">
									<div class="iq_auth_flex_200 iq_auth_padd_7 iq_auth_info_txt">
										<?php echo esc_html__('The logo will be displayed on the user authorization and registration page', 'registration-and-authorize'); ?><br>
										&bull; <?php echo esc_html__('Click image to update/download logo', 'registration-and-authorize'); ?><br>
										&bull; <?php echo esc_html__('Logo formats: .PNG or .SVG', 'registration-and-authorize'); ?><br>
										
										<div class="iq_auth_mt_20">
											<div class="iq_auth_li_head">
												<?php echo esc_html__('Logo width', 'registration-and-authorize'); ?>
											</div>
											<input type="text" id="logo_width" name="logo_width" class="iq_auth_input iq_auth_input_default iq_auth_max_w200 iq_auth_align_center" maxlength="10" placeholder="3" value="<?php echo esc_attr($FormVal['logo_width']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
										</div>
										
										<div class="iq_auth_mt_20">
											<div class="iq_auth_li_head">
												<?php echo esc_html__('Show logo', 'registration-and-authorize'); ?>?
											</div>
											<input class="iq_auth_tgl iq_auth_tgl_ios" id="logo_enable" name="logo_enable" type="checkbox" <?php echo esc_attr($FormVal['logo_enable']); ?>>
											<label class="iq_auth_tgl_btn" for="logo_enable"></label>
										</div>
									</div>
									<div class="iq_auth_flex_200 iq_auth_padd_7">
										<div class="iq_auth_sdt_upload_re">
											<label for="form_logo" class="iq_auth_filup_re full_width_b">
												<div id="icon_block" class=" pos_rel">
													<img src="<?php echo esc_url($logo_image); ?>" id="icon_id_src" class="iq_auth_sdt_img" alt="IQ Auth logo">
												</div>
												<input type="file" name="form_logo" id="form_logo" onchange="IQAuthPreviewImage(\'<?php echo esc_js('icon_id_src'); ?>\', this);" data-value="0" accept=".png,.svg">
											</label>
										</div>
									</div>
								</div>
							</li>
						</ul>
					</div>
				</div>
			
				<div class="iq_auth_flex_400">
					<div class="iq_auth_list_block iq_auth_flex_400 iq_auth_flexh">
						<h2 class="iq_auth_flextbl">
							<?php echo esc_html__('Login validation', 'registration-and-authorize'); ?>
						</h2>
						<ul class="iq_auth_ulcl">
						
							<!-- login_length -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Allowed length of the «Login» field', 'registration-and-authorize'); ?>
								</div>
								<div class="iq_auth_flexbox_st iq_auth_flexbox_yc iq_auth_flex_gap_2">
									<div>
										<input type="text" id="login_length_min" name="login_length_min" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="" value="<?php echo esc_attr($FormVal['login_length_min']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
									</div>
									<div>
										-
									</div>
									<div>
										<input type="text" id="login_length_max" name="login_length_max" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="" value="<?php echo esc_attr($FormVal['login_length_max']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
									</div>
								</div>
							</li>
							
							<!-- login_regex -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('REGEX validation for the «Login» field', 'registration-and-authorize'); ?>
								</div>
								<input type="text" id="login_regex" name="login_regex" class="iq_auth_input iq_auth_input_default iq_auth_full_width_b iq_auth_max_w700" maxlength="128" placeholder="" value="<?php echo esc_attr($FormVal['login_regex']); ?>">
							</li>
							
							<!-- login_regex_text -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Message to user if REGEX validation fails', 'registration-and-authorize'); ?>
								</div>
								<textarea id="login_regex_text" name="login_regex_text" class="iq_auth_textarea iq_auth_full_width_b iq_auth_max_w700" maxlength="300" rows="3"><?php echo esc_html($FormVal['login_regex_text']); ?></textarea>
							</li>
							
						</ul>
					</div>
				
					<div class="iq_auth_list_block iq_auth_flex_400 iq_auth_flexh">
						<h2 class="iq_auth_flextbl">
							<?php echo esc_html__('Email validation', 'registration-and-authorize'); ?>
						</h2>
						<ul class="iq_auth_ulcl">
						
							<!-- email_length -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Valid length of the «Email» field', 'registration-and-authorize'); ?>
								</div>
								<div class="iq_auth_flexbox_st iq_auth_flexbox_yc iq_auth_flex_gap_2">
									<div>
										<input type="text" id="email_length_min" name="email_length_min" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="" value="<?php echo esc_attr($FormVal['email_length_min']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
									</div>
									<div>
										-
									</div>
									<div>
										<input type="text" id="email_length_max" name="email_length_max" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="" value="<?php echo esc_attr($FormVal['email_length_max']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
									</div>
								</div>
							</li>
							
							<!-- email_regex -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('REGEX validation for «Email» field', 'registration-and-authorize'); ?>
								</div>
								<input type="text" id="email_regex" name="email_regex" class="iq_auth_input iq_auth_input_default iq_auth_full_width_b iq_auth_max_w700" maxlength="128" placeholder="" value="<?php echo esc_attr($FormVal['email_regex']); ?>">
							</li>
							
							<!-- email_regex_text -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Message to user if REGEX validation fails', 'registration-and-authorize'); ?>
								</div>
								<textarea id="email_regex_text" name="email_regex_text" class="iq_auth_textarea iq_auth_full_width_b iq_auth_max_w700" maxlength="300" rows="3"><?php echo esc_html($FormVal['email_regex_text']); ?></textarea>
							</li>
							
						</ul>
					</div>
				
					<div class="iq_auth_list_block iq_auth_flex_400 iq_auth_flexh">
						<h2 class="iq_auth_flextbl">
							<?php echo esc_html__('Password validation', 'registration-and-authorize'); ?>
						</h2>
						<ul class="iq_auth_ulcl">
						
							<!-- pass_length -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Valid length of the «Password» field', 'registration-and-authorize'); ?>
								</div>
								<div class="iq_auth_flexbox_st iq_auth_flexbox_yc iq_auth_flex_gap_2">
									<div>
										<input type="text" id="pass_length_min" name="pass_length_min" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="" value="<?php echo esc_attr($FormVal['pass_length_min']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
									</div>
									<div>
										-
									</div>
									<div>
										<input type="text" id="pass_length_max" name="pass_length_max" class="iq_auth_input iq_auth_input_default iq_auth_max_w70 iq_auth_align_center" maxlength="10" placeholder="" value="<?php echo esc_attr($FormVal['pass_length_max']); ?>" onkeyup="return IQAuthOnlyNum(this.id);">
									</div>
								</div>
							</li>
							
							<!-- pass_regex -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('REGEX validation for «Password» field', 'registration-and-authorize'); ?>
								</div>
								<input type="text" id="pass_regex" name="pass_regex" class="iq_auth_input iq_auth_input_default iq_auth_full_width_b iq_auth_max_w700" maxlength="128" placeholder="" value="<?php echo esc_attr($FormVal['pass_regex']); ?>">
							</li>
							
							<!-- pass_regex_text -->
							<li class="iq_auth_li">
								<div class="iq_auth_li_head">
									<?php echo esc_html__('Message to user if REGEX validation fails', 'registration-and-authorize'); ?>
								</div>
								<textarea id="pass_regex_text" name="pass_regex_text" class="iq_auth_textarea iq_auth_full_width_b iq_auth_max_w700" maxlength="300" rows="3"><?php echo esc_html($FormVal['pass_regex_text']); ?></textarea>
							</li>
							
						</ul>
					</div>
				</div>
				
			</div>
			<button type="submit" class="iq_auth_button_light_blue iq_auth_button_margin">
				<?php echo esc_html__('Save', 'registration-and-authorize'); ?>
			</button>
		</form>
</div>